@@ -24,11 +24,11 @@ Moonshine::Test - Test!
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -36,7 +36,7 @@ our $VERSION = '0.03';
 
     moon_test_one(
         test      => 'scalar',
-        meth      => \&Moonshine::Util::join_string,
+        meth      => \&Moonshine::Util::append_str,
         args      => [
             'first', 'second'       
         ],
@@ -109,6 +109,10 @@ moon_test_one can currently run the following tests.
 
 =item like - like - qr//,
 
+=item true - is - 1,
+
+=item false - is - 0,
+
 =back
 
 =head3 catch
@@ -156,7 +160,7 @@ sub moon_test_one {
             args      => { default => {} },
             args_list => 0,
             test      => 0,
-            expected  => 1,
+            expected  => 0,
             catch     => 0,
         }
     );
@@ -183,32 +187,38 @@ sub moon_test_one {
     }
 
     given ( $instruction{test} ) {
-        when (/ref/) {
+        when ('ref') {
             return is_deeply( $test[0], $expected[0],
                 "$test_name is ref - is_deeply" );
         }
-        when (/scalar/) {
+        when ('scalar') {
             return is( $test[0], $expected[0],
                 sprintf "%s is scalar - is - %s", $test_name, ($expected[0] // 'undef'));
         }
-        when (/hash/) {
+        when ('hash') {
             return is_deeply( {@test}, $expected[0],
                 "$test_name is hash - reference - is_deeply" );
         }
-        when (/array/) {
+        when ('array') {
             return is_deeply( \@test, $expected[0],
                 "$test_name is array - reference - is_deeply" );
         }
-        when (/obj/) {
+        when ('obj') {
             return is( blessed $test[0],
                 $expected[0],
                 "$test_name is Object - blessed - is - $expected[0]" );
         }
-        when (/like/) {
+        when ('like') {
             return like( $test[0], $expected[0],
                 "$test_name is like - $expected[0]" );
         }
-        when (/render/) {
+        when ('true') {
+            return is($test[0], 1, "$test_name is true - 1"); 
+        }
+        when ('false') {
+            return is($test[0], 0, "$test_name is false - 0");
+        }
+        when ('render') {
             return render_me(
                 instance => $test[0],
                 expected => $expected[0],
@@ -246,7 +256,7 @@ sub render_me {
     my %instruction = validate_with(
         params => \@_,
         spec   => {
-            instance => 1,
+            instance => 0,
             func     => 0,
             meth     => 0,
             args     => { default => {} },
